@@ -6,7 +6,8 @@ use Carp;
 use Tree::RB::Node qw[set_color color_of parent_of left_of right_of];
 use Tree::RB::Node::_Constants;
 use vars qw( $VERSION @EXPORT_OK );
-$VERSION = 0.500_003;
+$VERSION = '0.500006';
+$VERSION = eval $VERSION;
 
 require Exporter;
 *import    = \&Exporter::import;
@@ -246,6 +247,38 @@ sub lookup {
 *FETCH = \&lookup;
 *get   = \&lookup;
 
+sub nth {
+    my ($self, $i) = @_;
+
+    $i =~ /^-?\d+$/
+      or croak('Integer index expected');
+    if ($i < 0) {
+        $i += $self->[SIZE];
+    }
+    if ($i < 0 || $i >= $self->[SIZE]) {
+        return;
+    }
+
+    my ($node, $next, $moves);
+    if ($i > $self->[SIZE] / 2) {
+        $node = $self->max;
+        $next = 'predecessor';
+        $moves = $self->[SIZE] - $i - 1;
+    }
+    else {
+        $node = $self->min;
+        $next = 'successor';
+        $moves = $i;
+    }
+
+    my $count = 0;
+    while ($count != $moves) {
+        $node = $node->$next;
+        ++$count;
+    }
+    return $node;
+}
+
 sub EXISTS {
     my $self = shift;
     my $key  = shift;
@@ -303,6 +336,7 @@ sub put {
     }
     $self->_fix_after_insertion($z);
     $self->[SIZE]++;
+    return;
 }
 
 *STORE = \&put;
@@ -519,11 +553,6 @@ __END__
 Tree::RB - Perl implementation of the Red/Black tree, a type of balanced binary search tree. 
 
 
-=head1 VERSION
-
-This document describes Tree::RB version 0.1
-
-
 =head1 SYNOPSIS
 
     use Tree::RB;
@@ -536,27 +565,30 @@ This document describes Tree::RB version 0.1
     $tree->put('Egypt'   => 'Cairo');
     $tree->put('Germany' => 'Berlin');
 
-    $tree->put('Alaska' => 'Anchorage'); # D'oh!
+    $tree->put('Alaska' => 'Anchorage'); # D'oh! Alaska isn't a Country
     $tree->delete('Alaska');
 
-    print $tree->get('Ireland'); # 'Dublin'
+    print scalar $tree->get('Ireland'); # 'Dublin'
 
+    print $tree->size; # 6
     print $tree->min->key; # 'Egypt' 
     print $tree->max->key; # 'Ireland' 
-    print $tree->size; # 6
+
+    print $tree->nth(0)->key;  # 'Egypt' 
+    print $tree->nth(-1)->key; # 'Ireland' 
 
     # print items, ordered by key
     my $it = $tree->iter;
 
     while(my $node = $it->next) {
-        sprintf "key = %s, value = %s\n", $node->key, $node->val;
+        printf "key = %s, value = %s\n", $node->key, $node->val;
     }
 
     # print items in reverse order
     $it = $tree->rev_iter;
 
     while(my $node = $it->next) {
-        sprintf "key = %s, value = %s\n", $node->key, $node->val;
+        printf "key = %s, value = %s\n", $node->key, $node->val;
     }
 
     # Hash interface
@@ -583,7 +615,7 @@ This is a Perl implementation of the Red/Black tree, a type of balanced binary s
 
 A tied hash interface is also provided to allow ordered hashes to be used.
 
-See the Wikipedia article at L<http://en.wikipedia.org/wiki/Red-black_tree> for more on Red/Black trees.
+See the Wikipedia article at L<http://en.wikipedia.org/wiki/Red-black_tree> for further information about Red/Black trees.
 
 
 =head1 INTERFACE
@@ -608,7 +640,7 @@ For example, to get a case insensitive ordering
     my $it = $tree->iter;
 
     while(my $node = $it->next) {
-        sprintf "key = %s, value = %s\n", $node->key, $node->val;
+        printf "key = %s, value = %s\n", $node->key, $node->val;
     }
 
 =head2 resort(CODEREF)
@@ -636,6 +668,10 @@ Returns the node with the minimal key.
 
 Returns the node with the maximal key.
 
+=head2 nth(INDEX)
+
+Returns the node at the given (zero based) index, or undef if there is no node at that index. Negative indexes can be used, with -1 indicating the last node, -2 the penultimate node and so on.
+
 =head2 lookup(KEY, [MODE])
 
 When called in scalar context, lookup(KEY) returns the value
@@ -657,7 +693,7 @@ Tree::RB
 
 =item LUEQUAL
 
-Returns node exactly matching the key.
+This is the default mode. Returns the node exactly matching the key, or C<undef> if not found. 
 
 =item LUGTEQ
 
@@ -726,6 +762,10 @@ the node with key less than or equal to the specified key.
 
     $it = $tree->rev_iter('France');
     my $node = $it->next;
+    print $node->key; # -> 'France'
+
+    $it = $tree->rev_iter('Finland');
+    my $node = $it->next;
     print $node->key; # -> 'England'
 
 =head2 hseek(KEY, [{-reverse => 1|0}])
@@ -784,10 +824,8 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests to
-C<bug-tree-rb@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
+Please report any bugs or feature requests via the GitHub web interface at 
+L<https://github.com/arunbear/perl5-red-black-tree/issues>.
 
 =head1 AUTHOR
 
@@ -798,7 +836,7 @@ and Damian Ivereigh's libredblack (L<http://libredblack.sourceforge.net/>).
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks for bug reports go to Anton Petrusevich, Wes Thompson and Christopher Gurnee.
+Thanks for bug reports go to Anton Petrusevich, Wes Thompson, Petre Mierlutiu, Tomer Vromen, Christopher Gurnee and Ole Bjorn Hessen.
 
 =head1 LICENCE AND COPYRIGHT
 
